pub struct Event { /* private fields */ }Expand description
An event binding struct that sends a confirmation to the ccanvas server.
Implementations
Sourceimpl Event
impl Event
pub fn new( content: EventVariant, sender: UnboundedSender<Request>, confirm: u32, self_discrim: Discriminator, is_layout: bool, ) -> Self
Sourcepub fn done(&self, pass: bool)
pub fn done(&self, pass: bool)
Marks the event as done and releases the event.
trueallows other components to also recieve the event.falsecaptures the event.
Sourcepub fn get(&self) -> &EventVariant
pub fn get(&self) -> &EventVariant
Returns a reference to the content of the event.